@@ -12,14 +12,13 @@ def absjoin(*paths):
 
 thisdir = os.path.split(__file__)[0]
 scratch_dir = absjoin(thisdir, '../_scratch')
-# legacy acceptance test pptx files are in unit test file dir
-test_file_dir = absjoin(thisdir, '../../tests/test_files')
 # new ones should go here instead, others should be moved over
 test_pptx_dir = absjoin(thisdir, 'test_files')
 
 # legacy test pptx files ---------------
-no_core_props_pptx_path = absjoin(test_file_dir, 'no-core-props.pptx')
-test_image_path = absjoin(test_file_dir, 'python-powered.png')
+no_core_props_pptx_path = absjoin(
+    thisdir, '../../tests/test_files', 'no-core-props.pptx'
+)
 
 # scratch test pptx file ---------------
 saved_pptx_path = absjoin(scratch_dir, 'test_out.pptx')
@@ -44,6 +43,14 @@ def count(start=0, step=1):
         n += step
 
 
+def test_image(filename):
+    """
+    Return the absolute path to image file having *filename* in test_files
+    directory.
+    """
+    return absjoin(thisdir, 'test_files', filename)
+
+
 def test_pptx(name):
     """
     Return the absolute path to test .pptx file with root name *name*.
