@@ -9,13 +9,13 @@ from __future__ import absolute_import
 import os
 
 from behave import given, when, then
-from hamcrest import assert_that, is_, is_not, greater_than
 from StringIO import StringIO
 
 from pptx import Presentation
 from pptx.opc.constants import RELATIONSHIP_TYPE as RT
 from pptx.parts.presentation import _SlideMasters
 from pptx.parts.slidemaster import SlideMaster
+from pptx.util import Inches
 
 from .helpers import saved_pptx_path, test_pptx
 
@@ -64,8 +64,8 @@ def given_initialized_pptx_env(context):
 @when('I change the slide width and height')
 def when_change_slide_width_and_height(context):
     presentation = context.presentation
-    presentation.slide_width = 100000
-    presentation.slide_height = 200000
+    presentation.slide_width = Inches(4)
+    presentation.slide_height = Inches(3)
 
 
 @when('I construct a Presentation instance with no path argument')
@@ -147,13 +147,13 @@ def then_can_iterate_over_the_slide_masters(context):
 @then('I receive a presentation based on the default template')
 def then_receive_prs_based_on_def_tmpl(context):
     prs = context.prs
-    assert_that(prs, is_not(None))
+    assert prs is not None
     slide_masters = prs.slide_masters
-    assert_that(slide_masters, is_not(None))
-    assert_that(len(slide_masters), is_(1))
+    assert slide_masters is not None
+    assert len(slide_masters) == 1
     slide_layouts = slide_masters[0].slide_layouts
-    assert_that(slide_layouts, is_not(None))
-    assert_that(len(slide_layouts), is_(11))
+    assert slide_layouts is not None
+    assert len(slide_layouts) == 11
 
 
 @then('its slide height matches its known value')
@@ -170,10 +170,10 @@ def then_slide_width_matches_known_value(context):
 
 @then('I see the pptx file in the working directory')
 def then_see_pptx_file_in_working_dir(context):
-    assert_that(os.path.isfile(saved_pptx_path))
+    assert os.path.isfile(saved_pptx_path)
     minimum = 30000
     actual = os.path.getsize(saved_pptx_path)
-    assert_that(actual, is_(greater_than(minimum)))
+    assert actual > minimum
 
 
 @then('the external relationships are still there')
@@ -198,10 +198,10 @@ def then_len_of_slide_master_collection_is_2(context):
 @then('the slide height matches the new value')
 def then_slide_height_matches_new_value(context):
     presentation = context.presentation
-    assert presentation.slide_height == 200000
+    assert presentation.slide_height == Inches(3)
 
 
 @then('the slide width matches the new value')
 def then_slide_width_matches_new_value(context):
     presentation = context.presentation
-    assert presentation.slide_width == 100000
+    assert presentation.slide_width == Inches(4)
