@@ -7,11 +7,11 @@ writing presentations to and from a .pptx file.
 
 from __future__ import absolute_import
 
-from ..oxml.shared import serialize_part_xml
 from pptx.util import lazyproperty
 
 from .constants import RELATIONSHIP_TYPE as RT
-from .oxml import CT_Relationships, nsmap
+from .oxml import CT_Relationships, serialize_part_xml
+from ..oxml import parse_xml
 from .packuri import PACKAGE_URI, PackURI
 from .pkgreader import PackageReader
 from .pkgwriter import PackageWriter
@@ -26,6 +26,15 @@ class OpcPackage(object):
     def __init__(self):
         super(OpcPackage, self).__init__()
 
+    def after_unmarshal(self):
+        """
+        Called by loading code after all parts and relationships have been
+        loaded, to afford the opportunity for any required post-processing.
+        This one does nothing other than catch the call if a subclass
+        doesn't.
+        """
+        pass
+
     def iter_parts(self):
         """
         Generate exactly one reference to each of the parts in the package by
@@ -68,6 +77,20 @@ class OpcPackage(object):
         """
         return self.part_related_by(RT.OFFICE_DOCUMENT)
 
+    def next_partname(self, tmpl):
+        """
+        Return a |PackURI| instance representing the next available partname
+        matching *tmpl*, which is a printf (%)-style template string
+        containing a single replacement item, a '%d' to be used to insert the
+        integer portion of the partname. Example: '/ppt/slides/slide%d.xml'
+        """
+        partnames = [part.partname for part in self.iter_parts()]
+        for n in range(1, len(partnames)+2):
+            candidate_partname = tmpl % n
+            if candidate_partname not in partnames:
+                return PackURI(candidate_partname)
+        raise Exception('ProgrammingError: ran out of candidate_partnames')
+
     @classmethod
     def open(cls, pkg_file):
         """
@@ -116,7 +139,6 @@ class OpcPackage(object):
         Save this package to *pkg_file*, where *file* can be either a path to
         a file (a string) or a file-like object.
         """
-        # self._notify_before_marshal()
         for part in self.parts:
             part.before_marshal()
         PackageWriter.write(pkg_file, self.rels, self.parts)
@@ -128,14 +150,11 @@ class Part(object):
     intended to be subclassed in client code to implement specific part
     behaviors.
     """
-    def __init__(
-            self, partname, content_type, blob=None, element=None,
-            package=None):
+    def __init__(self, partname, content_type, blob=None, package=None):
         super(Part, self).__init__()
         self._partname = partname
         self._content_type = content_type
         self._blob = blob
-        self._element = element
         self._package = package
 
     # load/save interface to OpcPackage ------------------------------
@@ -167,10 +186,17 @@ class Part(object):
         binary. Intended to be overridden by subclasses. Default behavior is
         to return load blob.
         """
-        if self._element is not None:
-            return serialize_part_xml(self._element)
         return self._blob
 
+    @blob.setter
+    def blob(self, bytes_):
+        """
+        Note that not all subclasses use the part blob as their blob source.
+        In particular, the |XmlPart| subclass uses its `self._element` to
+        serialize a blob on demand. This works find for binary parts though.
+        """
+        self._blob = bytes_
+
     @property
     def content_type(self):
         """
@@ -180,9 +206,7 @@ class Part(object):
 
     @classmethod
     def load(cls, partname, content_type, blob, package):
-        return cls(
-            partname, content_type, blob=blob, element=None, package=package
-        )
+        return cls(partname, content_type, blob, package)
 
     def load_rel(self, reltype, target, rId, is_external=False):
         """
@@ -195,6 +219,13 @@ class Part(object):
         """
         return self.rels.add_relationship(reltype, target, rId, is_external)
 
+    @property
+    def package(self):
+        """
+        |OpcPackage| instance this part belongs to.
+        """
+        return self._package
+
     @property
     def partname(self):
         """
@@ -271,18 +302,40 @@ class Part(object):
         Return the count of references in this part's XML to the relationship
         identified by *rId*.
         """
-        assert self._element is not None
-        rIds = self._element.xpath('//@r:id', namespaces=nsmap)
+        rIds = self._element.xpath('//@r:id')
         return len([_rId for _rId in rIds if _rId == rId])
 
-    # ----------------------------------------------------------------
+
+class XmlPart(Part):
+    """
+    Base class for package parts containing an XML payload, which is most of
+    them. Provides additional methods to the |Part| base class that take care
+    of parsing and reserializing the XML payload and managing relationships
+    to other parts.
+    """
+    def __init__(self, partname, content_type, element, package=None):
+        super(XmlPart, self).__init__(
+            partname, content_type, package=package
+        )
+        self._element = element
 
     @property
-    def package(self):
+    def blob(self):
+        return serialize_part_xml(self._element)
+
+    @classmethod
+    def load(cls, partname, content_type, blob, package):
+        element = parse_xml(blob)
+        return cls(partname, content_type, element, package)
+
+    @property
+    def part(self):
         """
-        |OpcPackage| instance this part belongs to.
+        Part of the parent protocol, "children" of the document will not know
+        the part that contains them so must ask their parent object. That
+        chain of delegation ends here for child objects.
         """
-        return self._package
+        return self
 
 
 class PartFactory(object):
